==> lxqt-panel_0.16.1.orig.tar.xz: lxqt-panel-0.16.1/plugin-kbindicator/translations/kbindicator_nb_NO.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nb_NO">
<context>
    <name>Content</name>
    <message>
        <location filename="../src/content.cpp" line="46"/>
        <source>C</source>
        <comment>Label for CapsLock indicator</comment>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/content.cpp" line="49"/>
        <source>CapsLock</source>
        <comment>Tooltip for CapsLock indicator</comment>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/content.cpp" line="53"/>
        <source>N</source>
        <comment>Label for NumLock indicator</comment>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/content.cpp" line="55"/>
        <source>NumLock</source>
        <comment>Tooltip for NumLock indicator</comment>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/content.cpp" line="60"/>
        <source>S</source>
        <comment>Label for ScrollLock indicator</comment>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/content.cpp" line="62"/>
        <source>ScrollLock</source>
        <comment>Tooltip for ScrollLock indicator</comment>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/content.cpp" line="105"/>
        <source>Layout</source>
        <translation>Tastaturspråk</translation>
    </message>
    <message>
        <location filename="../src/content.cpp" line="105"/>
        <source>Variant</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>KbdStateConfig</name>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="14"/>
        <source>Keyboard state settings</source>
        <translation>Innstillinger for tastaturtilstand</translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="20"/>
        <source>Lock Indicators</source>
        <translation>Indikatorer for låsetaster</translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="26"/>
        <source>Show Caps Lock</source>
        <translation>Vis CapsLock</translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="33"/>
        <source>Show Num Lock</source>
        <translation>Vis NumLock</translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="40"/>
        <source>Show Scroll Lock</source>
        <translation>Vis ScrollLock</translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="50"/>
        <source>Keyboard Layout Indicator</source>
        <translation>Indikator for tastaturlayout</translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="62"/>
        <source>Switching policy</source>
        <translation>Bytt tastaturspråk</translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="99"/>
        <source>Flags path pattern:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="106"/>
        <source>File path pattern for country flags. Must contain &lt;strong&gt;%1&lt;/strong&gt; which is replaced by the two letter ISO country code (lower case).&lt;br&gt;&lt;br&gt;Example: /usr/share/iso-flags-svg/country-squared/%1.svg</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="116"/>
        <source>Configure layouts</source>
        <translation>Still inn tastaturlayout</translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="69"/>
        <source>Global</source>
        <translation>Over alt</translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="79"/>
        <source>Window</source>
        <translation>Per vindu</translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="89"/>
        <source>Application</source>
        <translation>Per program</translation>
    </message>
</context>
</TS>

==> lxqt-panel_1.4.0.orig.tar.xz: lxqt-panel-1.4.0/plugin-kbindicator/translations/kbindicator_nb_NO.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nb_NO">
<context>
    <name>Content</name>
    <message>
        <location filename="../src/content.cpp" line="46"/>
        <source>C</source>
        <comment>Label for CapsLock indicator</comment>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/content.cpp" line="49"/>
        <source>CapsLock</source>
        <comment>Tooltip for CapsLock indicator</comment>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/content.cpp" line="53"/>
        <source>N</source>
        <comment>Label for NumLock indicator</comment>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/content.cpp" line="55"/>
        <source>NumLock</source>
        <comment>Tooltip for NumLock indicator</comment>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/content.cpp" line="60"/>
        <source>S</source>
        <comment>Label for ScrollLock indicator</comment>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/content.cpp" line="62"/>
        <source>ScrollLock</source>
        <comment>Tooltip for ScrollLock indicator</comment>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/content.cpp" line="104"/>
        <source>Layout</source>
        <translation>Tastaturspråk</translation>
    </message>
    <message>
        <location filename="../src/content.cpp" line="104"/>
        <source>Variant</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>KbdStateConfig</name>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="14"/>
        <source>Keyboard state settings</source>
        <translation>Innstillinger for tastaturtilstand</translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="20"/>
        <source>Lock Indicators</source>
        <translation>Indikatorer for låsetaster</translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="26"/>
        <source>Show Caps Lock</source>
        <translation>Vis CapsLock</translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="33"/>
        <source>Show Num Lock</source>
        <translation>Vis NumLock</translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="40"/>
        <source>Show Scroll Lock</source>
        <translation>Vis ScrollLock</translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="50"/>
        <source>Keyboard Layout Indicator</source>
        <translation>Indikator for tastaturlayout</translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="62"/>
        <source>Switching policy</source>
        <translation>Bytt tastaturspråk</translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="99"/>
        <source>Flags path pattern:</source>
        <translation>Stimønster for flagg:</translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="106"/>
        <source>File path pattern for country flags. Must contain &lt;strong&gt;%1&lt;/strong&gt; which is replaced by the two letter ISO country code (lower case).&lt;br&gt;&lt;br&gt;Example: /usr/share/iso-flags-svg/country-squared/%1.svg</source>
        <translation>Filstimønster for språkflagg. Må inneholde &lt;strong&gt;%1&lt;/strong&gt;som erstattes av ISO-kode på to (små) bokstaver.&lt;br&gt;&lt;br&gt;Eksempel: /usr/share/iso-flags-svg/country-squared/%1.svg</translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="116"/>
        <source>Configure layouts</source>
        <translation>Still inn tastaturlayout</translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="69"/>
        <source>Global</source>
        <translation>Over alt</translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="79"/>
        <source>Window</source>
        <translation>Per vindu</translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="89"/>
        <source>Application</source>
        <translation>Per program</translation>
    </message>
</context>
</TS>
